# Project Title

The reloreta module implements the ReLORETA algorithm from the article 
"A Robust eLORETA Technique for Localization of Brain Sources in the Presence of Forward Model Uncertainties", Noroozi. A et al, 2022

## Installation

You can install the package as follows: 
pip install reloreta 
or using the following for IPython: 
!pip install reloreta

## Example 
For the complete example of how to use and apply the module, please see the following page: 
https://github.com/AminNoroozi/ReLORETA

## License
This project is licensed under the MIT License. See the LICENSE file for details.

## Contact
Author: Amin Noroozi
Email: amin.noroozi555@gmail.com
GitHub: https://github.com/AminNoroozi